@@ -14,5 +14,5 @@ if __name__ == '__main__':
             'The port on which to listen',
         default = 16080)
 
-    main(**vars(parser.parse_args()))
+    main(**vars(parser.parse_args())).serve_forever()
 
