@@ -1,5 +1,6 @@
 exports.toolbar = (function() {
-    var module = {};
+    var module = {
+        EL: "toolbar"};
 
     /**
      * The toolbar.
@@ -23,7 +24,7 @@ exports.toolbar = (function() {
     module.Toolbar = Toolbar;
 
     /**
-     * Applies styles necessary fo this type of toolbar class.
+     * Applies styles necessary for this type of toolbar class.
      *
      * This function also sets up methods to handle touch events.
      */
@@ -193,6 +194,43 @@ exports.toolbar = (function() {
         event.preventDefault();
     };
 
+    /**
+     * Finds all Toolbar instances by CSS selector.
+     *
+     * @param selector
+     *     The CSS selector to use.
+     * @return a list of Toolbar instances
+     */
+    module.find = function(selector) {
+        var els = document.querySelectorAll(selector);
+        var result = [];
+
+        for (var i = 0; i < els.length; i++) {
+            var el = els[i];
+
+            if (el.toolbar) {
+                result.push(el.toolbar);
+            }
+        }
+
+        return result;
+    };
+
+    /**
+     * Automatically instantiate all toolbars when the document is loaded.
+     */
+    exports.onloadCallbacks.push(function() {
+        var els = document.querySelectorAll(module.EL);
+
+        for (var i = 0; i < els.length; i++) {
+            var el = els[i];
+            el.toolbar = new Toolbar(el);
+
+            // Hide the toolbar after a while
+            setTimeout(el.toolbar.hide.bind(el.toolbar), 2000);
+        }
+    });
+
     return module;
 })();
 
