@@ -49,9 +49,8 @@ exports.view = (function() {
         var d = Math.sqrt(dx * dx + dy * dy);
         var a = Math.atan2(dy, dx);
 
-        // TODO: Make configurable
-        var acceleration = 0.3;
-        var sensitivity = 1.5;
+        var acceleration = configuration.get("view.acceleration", 0.3);
+        var sensitivity = configuration.get("view.sensitivity", 1.5);
 
         var h = sensitivity * Math.pow(d, 1.0 + acceleration);
 
@@ -69,9 +68,12 @@ exports.view = (function() {
         var dx = newTouch.screenX - oldTouch.screenX;
         var dy = newTouch.screenY - oldTouch.screenY;
 
-        // TODO: Make configurable
-        var xdirection = -1;
-        var ydirection = -1;
+        var xdirection = configuration.get("view.naturalScroll", true)
+            ? -1
+            : 1;
+        var ydirection = configuration.get("view.naturalScroll", true)
+            ? -1
+            : 1;
 
         return [dx * xdirection, dy * ydirection];
     }
